@@ -232,6 +232,11 @@ prepareLinux()
                     cat /etc/lsb-release | grep "DISTRIB_RELEASE=18." >/dev/null
                     if [ $? = 0 ] ; then
                         OSTYPE=UBUNTU18
+                    else
+                        cat /etc/lsb-release | grep "DISTRIB_RELEASE=20." >/dev/null
+                        if [ $? = 0 ] ; then
+                            OSTYPE=UBUNTU20
+                        fi
                     fi
                 fi
             fi
@@ -259,7 +264,7 @@ prepareLinux()
         
         #other debian OS, we still can 
         if [ "${OSTYPE}" = "unknowlinux" ] ; then
-            echo It seems you are not using ubuntu 14,16,18 and Debian 7/8/9/10.
+            echo It seems you are not using ubuntu 14,16,18,20 and Debian 7/8/9/10.
             echo But we still can try to go further.
         fi
         
@@ -528,7 +533,9 @@ git clone https://github.com/litespeedtech/third-party.git
 mv third-party thirdparty
 mkdir thirdparty/lib64
 cd thirdparty/script/
-
+git pull
+#Only for 1.6.14
+git reset --hard 41eab3fb08ba59229382e3edf8e0cc5e26d1c03e
 
  
 sed -i -e "s/unittest-cpp/ /g" ./build_ols.sh
