@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -112,7 +112,12 @@ int main(int argc, char *argv[])
 }
 
 
+//#define WANT_LSAN
 #ifndef WANT_LSAN
-extern "C" const char* __asan_default_options() { return "detect_leaks=0"; }
+extern "C" const char* __asan_default_options()
+{ return "disable_coredump=0:unmap_shadow_on_exit=1:detect_leaks=0:abort_on_error=1"; }
+#else
+extern "C" const char* __asan_default_options()
+{ return "disable_coredump=0:unmap_shadow_on_exit=1:abort_on_error=1"; }
 #endif
 
